# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.appengine.v1",
    manifest={"OperationMetadataV1", "CreateVersionMetadataV1",},
)


class OperationMetadataV1(proto.Message):
    r"""Metadata for the given
    [google.longrunning.Operation][google.longrunning.Operation].

    Attributes:
        method (str):
            API method that initiated this operation. Example:
            ``google.appengine.v1.Versions.CreateVersion``.

            @OutputOnly
        insert_time (google.protobuf.timestamp_pb2.Timestamp):
            Time that this operation was created.
            @OutputOnly
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Time that this operation completed.
            @OutputOnly
        user (str):
            User who requested this operation.
            @OutputOnly
        target (str):
            Name of the resource that this operation is acting on.
            Example: ``apps/myapp/services/default``.

            @OutputOnly
        ephemeral_message (str):
            Ephemeral message that may change every time
            the operation is polled. @OutputOnly
        warning (Sequence[str]):
            Durable messages that persist on every
            operation poll. @OutputOnly
        create_version_metadata (google.cloud.appengine_admin_v1.types.CreateVersionMetadataV1):

    """

    method = proto.Field(proto.STRING, number=1,)
    insert_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    user = proto.Field(proto.STRING, number=4,)
    target = proto.Field(proto.STRING, number=5,)
    ephemeral_message = proto.Field(proto.STRING, number=6,)
    warning = proto.RepeatedField(proto.STRING, number=7,)
    create_version_metadata = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="method_metadata",
        message="CreateVersionMetadataV1",
    )


class CreateVersionMetadataV1(proto.Message):
    r"""Metadata for the given
    [google.longrunning.Operation][google.longrunning.Operation] during
    a
    [google.appengine.v1.CreateVersionRequest][google.appengine.v1.CreateVersionRequest].

    Attributes:
        cloud_build_id (str):
            The Cloud Build ID if one was created as part
            of the version create. @OutputOnly
    """

    cloud_build_id = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.appengine_admin_v1.types import application as ga_application
from google.cloud.appengine_admin_v1.types import certificate as ga_certificate
from google.cloud.appengine_admin_v1.types import domain
from google.cloud.appengine_admin_v1.types import domain_mapping as ga_domain_mapping
from google.cloud.appengine_admin_v1.types import firewall
from google.cloud.appengine_admin_v1.types import instance
from google.cloud.appengine_admin_v1.types import service as ga_service
from google.cloud.appengine_admin_v1.types import version as ga_version
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.appengine.v1",
    manifest={
        "VersionView",
        "AuthorizedCertificateView",
        "DomainOverrideStrategy",
        "GetApplicationRequest",
        "CreateApplicationRequest",
        "UpdateApplicationRequest",
        "RepairApplicationRequest",
        "ListServicesRequest",
        "ListServicesResponse",
        "GetServiceRequest",
        "UpdateServiceRequest",
        "DeleteServiceRequest",
        "ListVersionsRequest",
        "ListVersionsResponse",
        "GetVersionRequest",
        "CreateVersionRequest",
        "UpdateVersionRequest",
        "DeleteVersionRequest",
        "ListInstancesRequest",
        "ListInstancesResponse",
        "GetInstanceRequest",
        "DeleteInstanceRequest",
        "DebugInstanceRequest",
        "ListIngressRulesRequest",
        "ListIngressRulesResponse",
        "BatchUpdateIngressRulesRequest",
        "BatchUpdateIngressRulesResponse",
        "CreateIngressRuleRequest",
        "GetIngressRuleRequest",
        "UpdateIngressRuleRequest",
        "DeleteIngressRuleRequest",
        "ListAuthorizedDomainsRequest",
        "ListAuthorizedDomainsResponse",
        "ListAuthorizedCertificatesRequest",
        "ListAuthorizedCertificatesResponse",
        "GetAuthorizedCertificateRequest",
        "CreateAuthorizedCertificateRequest",
        "UpdateAuthorizedCertificateRequest",
        "DeleteAuthorizedCertificateRequest",
        "ListDomainMappingsRequest",
        "ListDomainMappingsResponse",
        "GetDomainMappingRequest",
        "CreateDomainMappingRequest",
        "UpdateDomainMappingRequest",
        "DeleteDomainMappingRequest",
    },
)


class VersionView(proto.Enum):
    r"""Fields that should be returned when
    [Version][google.appengine.v1.Version] resources are retrieved.
    """
    BASIC = 0
    FULL = 1


class AuthorizedCertificateView(proto.Enum):
    r"""Fields that should be returned when an AuthorizedCertificate
    resource is retrieved.
    """
    BASIC_CERTIFICATE = 0
    FULL_CERTIFICATE = 1


class DomainOverrideStrategy(proto.Enum):
    r"""Override strategy for mutating an existing mapping."""
    UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY = 0
    STRICT = 1
    OVERRIDE = 2


class GetApplicationRequest(proto.Message):
    r"""Request message for ``Applications.GetApplication``.
    Attributes:
        name (str):
            Name of the Application resource to get. Example:
            ``apps/myapp``.
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateApplicationRequest(proto.Message):
    r"""Request message for ``Applications.CreateApplication``.
    Attributes:
        application (google.cloud.appengine_admin_v1.types.Application):
            Application configuration.
    """

    application = proto.Field(
        proto.MESSAGE, number=2, message=ga_application.Application,
    )


class UpdateApplicationRequest(proto.Message):
    r"""Request message for ``Applications.UpdateApplication``.
    Attributes:
        name (str):
            Name of the Application resource to update. Example:
            ``apps/myapp``.
        application (google.cloud.appengine_admin_v1.types.Application):
            An Application containing the updated
            resource.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to
            be updated.
    """

    name = proto.Field(proto.STRING, number=1,)
    application = proto.Field(
        proto.MESSAGE, number=2, message=ga_application.Application,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class RepairApplicationRequest(proto.Message):
    r"""Request message for 'Applications.RepairApplication'.
    Attributes:
        name (str):
            Name of the application to repair. Example: ``apps/myapp``
    """

    name = proto.Field(proto.STRING, number=1,)


class ListServicesRequest(proto.Message):
    r"""Request message for ``Services.ListServices``.
    Attributes:
        parent (str):
            Name of the parent Application resource. Example:
            ``apps/myapp``.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListServicesResponse(proto.Message):
    r"""Response message for ``Services.ListServices``.
    Attributes:
        services (Sequence[google.cloud.appengine_admin_v1.types.Service]):
            The services belonging to the requested
            application.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    services = proto.RepeatedField(proto.MESSAGE, number=1, message=ga_service.Service,)
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetServiceRequest(proto.Message):
    r"""Request message for ``Services.GetService``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default``.
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateServiceRequest(proto.Message):
    r"""Request message for ``Services.UpdateService``.
    Attributes:
        name (str):
            Name of the resource to update. Example:
            ``apps/myapp/services/default``.
        service (google.cloud.appengine_admin_v1.types.Service):
            A Service resource containing the updated
            service. Only fields set in the field mask will
            be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to
            be updated.
        migrate_traffic (bool):
            Set to ``true`` to gradually shift traffic to one or more
            versions that you specify. By default, traffic is shifted
            immediately. For gradual traffic migration, the target
            versions must be located within instances that are
            configured for both `warmup
            requests <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#InboundServiceType>`__
            and `automatic
            scaling <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#AutomaticScaling>`__.
            You must specify the
            ```shardBy`` <https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services#ShardBy>`__
            field in the Service resource. Gradual traffic migration is
            not supported in the App Engine flexible environment. For
            examples, see `Migrating and Splitting
            Traffic <https://cloud.google.com/appengine/docs/admin-api/migrating-splitting-traffic>`__.
    """

    name = proto.Field(proto.STRING, number=1,)
    service = proto.Field(proto.MESSAGE, number=2, message=ga_service.Service,)
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )
    migrate_traffic = proto.Field(proto.BOOL, number=4,)


class DeleteServiceRequest(proto.Message):
    r"""Request message for ``Services.DeleteService``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default``.
    """

    name = proto.Field(proto.STRING, number=1,)


class ListVersionsRequest(proto.Message):
    r"""Request message for ``Versions.ListVersions``.
    Attributes:
        parent (str):
            Name of the parent Service resource. Example:
            ``apps/myapp/services/default``.
        view (google.cloud.appengine_admin_v1.types.VersionView):
            Controls the set of fields returned in the ``List``
            response.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    view = proto.Field(proto.ENUM, number=2, enum="VersionView",)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListVersionsResponse(proto.Message):
    r"""Response message for ``Versions.ListVersions``.
    Attributes:
        versions (Sequence[google.cloud.appengine_admin_v1.types.Version]):
            The versions belonging to the requested
            service.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    versions = proto.RepeatedField(proto.MESSAGE, number=1, message=ga_version.Version,)
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetVersionRequest(proto.Message):
    r"""Request message for ``Versions.GetVersion``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default/versions/v1``.
        view (google.cloud.appengine_admin_v1.types.VersionView):
            Controls the set of fields returned in the ``Get`` response.
    """

    name = proto.Field(proto.STRING, number=1,)
    view = proto.Field(proto.ENUM, number=2, enum="VersionView",)


class CreateVersionRequest(proto.Message):
    r"""Request message for ``Versions.CreateVersion``.
    Attributes:
        parent (str):
            Name of the parent resource to create this version under.
            Example: ``apps/myapp/services/default``.
        version (google.cloud.appengine_admin_v1.types.Version):
            Application deployment configuration.
    """

    parent = proto.Field(proto.STRING, number=1,)
    version = proto.Field(proto.MESSAGE, number=2, message=ga_version.Version,)


class UpdateVersionRequest(proto.Message):
    r"""Request message for ``Versions.UpdateVersion``.
    Attributes:
        name (str):
            Name of the resource to update. Example:
            ``apps/myapp/services/default/versions/1``.
        version (google.cloud.appengine_admin_v1.types.Version):
            A Version containing the updated resource.
            Only fields set in the field mask will be
            updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to
            be updated.
    """

    name = proto.Field(proto.STRING, number=1,)
    version = proto.Field(proto.MESSAGE, number=2, message=ga_version.Version,)
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeleteVersionRequest(proto.Message):
    r"""Request message for ``Versions.DeleteVersion``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default/versions/v1``.
    """

    name = proto.Field(proto.STRING, number=1,)


class ListInstancesRequest(proto.Message):
    r"""Request message for ``Instances.ListInstances``.
    Attributes:
        parent (str):
            Name of the parent Version resource. Example:
            ``apps/myapp/services/default/versions/v1``.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListInstancesResponse(proto.Message):
    r"""Response message for ``Instances.ListInstances``.
    Attributes:
        instances (Sequence[google.cloud.appengine_admin_v1.types.Instance]):
            The instances belonging to the requested
            version.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    instances = proto.RepeatedField(proto.MESSAGE, number=1, message=instance.Instance,)
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetInstanceRequest(proto.Message):
    r"""Request message for ``Instances.GetInstance``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default/versions/v1/instances/instance-1``.
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteInstanceRequest(proto.Message):
    r"""Request message for ``Instances.DeleteInstance``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default/versions/v1/instances/instance-1``.
    """

    name = proto.Field(proto.STRING, number=1,)


class DebugInstanceRequest(proto.Message):
    r"""Request message for ``Instances.DebugInstance``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/services/default/versions/v1/instances/instance-1``.
        ssh_key (str):
            Public SSH key to add to the instance. Examples:

            -  ``[USERNAME]:ssh-rsa [KEY_VALUE] [USERNAME]``
            -  ``[USERNAME]:ssh-rsa [KEY_VALUE] google-ssh {"userName":"[USERNAME]","expireOn":"[EXPIRE_TIME]"}``

            For more information, see `Adding and Removing SSH
            Keys <https://cloud.google.com/compute/docs/instances/adding-removing-ssh-keys>`__.
    """

    name = proto.Field(proto.STRING, number=1,)
    ssh_key = proto.Field(proto.STRING, number=2,)


class ListIngressRulesRequest(proto.Message):
    r"""Request message for ``Firewall.ListIngressRules``.
    Attributes:
        parent (str):
            Name of the Firewall collection to retrieve. Example:
            ``apps/myapp/firewall/ingressRules``.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
        matching_address (str):
            A valid IP Address. If set, only rules
            matching this address will be returned. The
            first returned rule will be the rule that fires
            on requests from this IP.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)
    matching_address = proto.Field(proto.STRING, number=4,)


class ListIngressRulesResponse(proto.Message):
    r"""Response message for ``Firewall.ListIngressRules``.
    Attributes:
        ingress_rules (Sequence[google.cloud.appengine_admin_v1.types.FirewallRule]):
            The ingress FirewallRules for this
            application.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    ingress_rules = proto.RepeatedField(
        proto.MESSAGE, number=1, message=firewall.FirewallRule,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class BatchUpdateIngressRulesRequest(proto.Message):
    r"""Request message for ``Firewall.BatchUpdateIngressRules``.
    Attributes:
        name (str):
            Name of the Firewall collection to set. Example:
            ``apps/myapp/firewall/ingressRules``.
        ingress_rules (Sequence[google.cloud.appengine_admin_v1.types.FirewallRule]):
            A list of FirewallRules to replace the
            existing set.
    """

    name = proto.Field(proto.STRING, number=1,)
    ingress_rules = proto.RepeatedField(
        proto.MESSAGE, number=2, message=firewall.FirewallRule,
    )


class BatchUpdateIngressRulesResponse(proto.Message):
    r"""Response message for ``Firewall.UpdateAllIngressRules``.
    Attributes:
        ingress_rules (Sequence[google.cloud.appengine_admin_v1.types.FirewallRule]):
            The full list of ingress FirewallRules for
            this application.
    """

    ingress_rules = proto.RepeatedField(
        proto.MESSAGE, number=1, message=firewall.FirewallRule,
    )


class CreateIngressRuleRequest(proto.Message):
    r"""Request message for ``Firewall.CreateIngressRule``.
    Attributes:
        parent (str):
            Name of the parent Firewall collection in which to create a
            new rule. Example: ``apps/myapp/firewall/ingressRules``.
        rule (google.cloud.appengine_admin_v1.types.FirewallRule):
            A FirewallRule containing the new resource.
            The user may optionally provide a position at
            which the new rule will be placed. The positions
            define a sequential list starting at 1. If a
            rule already exists at the given position, rules
            greater than the provided position will be moved
            forward by one.

            If no position is provided, the server will
            place the rule as the second to last rule in the
            sequence before the required default allow-all
            or deny-all rule.
    """

    parent = proto.Field(proto.STRING, number=1,)
    rule = proto.Field(proto.MESSAGE, number=2, message=firewall.FirewallRule,)


class GetIngressRuleRequest(proto.Message):
    r"""Request message for ``Firewall.GetIngressRule``.
    Attributes:
        name (str):
            Name of the Firewall resource to retrieve. Example:
            ``apps/myapp/firewall/ingressRules/100``.
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateIngressRuleRequest(proto.Message):
    r"""Request message for ``Firewall.UpdateIngressRule``.
    Attributes:
        name (str):
            Name of the Firewall resource to update. Example:
            ``apps/myapp/firewall/ingressRules/100``.
        rule (google.cloud.appengine_admin_v1.types.FirewallRule):
            A FirewallRule containing the updated
            resource
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to
            be updated.
    """

    name = proto.Field(proto.STRING, number=1,)
    rule = proto.Field(proto.MESSAGE, number=2, message=firewall.FirewallRule,)
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeleteIngressRuleRequest(proto.Message):
    r"""Request message for ``Firewall.DeleteIngressRule``.
    Attributes:
        name (str):
            Name of the Firewall resource to delete. Example:
            ``apps/myapp/firewall/ingressRules/100``.
    """

    name = proto.Field(proto.STRING, number=1,)


class ListAuthorizedDomainsRequest(proto.Message):
    r"""Request message for ``AuthorizedDomains.ListAuthorizedDomains``.
    Attributes:
        parent (str):
            Name of the parent Application resource. Example:
            ``apps/myapp``.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListAuthorizedDomainsResponse(proto.Message):
    r"""Response message for ``AuthorizedDomains.ListAuthorizedDomains``.
    Attributes:
        domains (Sequence[google.cloud.appengine_admin_v1.types.AuthorizedDomain]):
            The authorized domains belonging to the user.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    domains = proto.RepeatedField(
        proto.MESSAGE, number=1, message=domain.AuthorizedDomain,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class ListAuthorizedCertificatesRequest(proto.Message):
    r"""Request message for
    ``AuthorizedCertificates.ListAuthorizedCertificates``.

    Attributes:
        parent (str):
            Name of the parent ``Application`` resource. Example:
            ``apps/myapp``.
        view (google.cloud.appengine_admin_v1.types.AuthorizedCertificateView):
            Controls the set of fields returned in the ``LIST``
            response.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    view = proto.Field(proto.ENUM, number=4, enum="AuthorizedCertificateView",)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListAuthorizedCertificatesResponse(proto.Message):
    r"""Response message for
    ``AuthorizedCertificates.ListAuthorizedCertificates``.

    Attributes:
        certificates (Sequence[google.cloud.appengine_admin_v1.types.AuthorizedCertificate]):
            The SSL certificates the user is authorized
            to administer.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    certificates = proto.RepeatedField(
        proto.MESSAGE, number=1, message=ga_certificate.AuthorizedCertificate,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetAuthorizedCertificateRequest(proto.Message):
    r"""Request message for
    ``AuthorizedCertificates.GetAuthorizedCertificate``.

    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/authorizedCertificates/12345``.
        view (google.cloud.appengine_admin_v1.types.AuthorizedCertificateView):
            Controls the set of fields returned in the ``GET`` response.
    """

    name = proto.Field(proto.STRING, number=1,)
    view = proto.Field(proto.ENUM, number=2, enum="AuthorizedCertificateView",)


class CreateAuthorizedCertificateRequest(proto.Message):
    r"""Request message for
    ``AuthorizedCertificates.CreateAuthorizedCertificate``.

    Attributes:
        parent (str):
            Name of the parent ``Application`` resource. Example:
            ``apps/myapp``.
        certificate (google.cloud.appengine_admin_v1.types.AuthorizedCertificate):
            SSL certificate data.
    """

    parent = proto.Field(proto.STRING, number=1,)
    certificate = proto.Field(
        proto.MESSAGE, number=2, message=ga_certificate.AuthorizedCertificate,
    )


class UpdateAuthorizedCertificateRequest(proto.Message):
    r"""Request message for
    ``AuthorizedCertificates.UpdateAuthorizedCertificate``.

    Attributes:
        name (str):
            Name of the resource to update. Example:
            ``apps/myapp/authorizedCertificates/12345``.
        certificate (google.cloud.appengine_admin_v1.types.AuthorizedCertificate):
            An ``AuthorizedCertificate`` containing the updated
            resource. Only fields set in the field mask will be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to be updated.
            Updates are only supported on the ``certificate_raw_data``
            and ``display_name`` fields.
    """

    name = proto.Field(proto.STRING, number=1,)
    certificate = proto.Field(
        proto.MESSAGE, number=2, message=ga_certificate.AuthorizedCertificate,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeleteAuthorizedCertificateRequest(proto.Message):
    r"""Request message for
    ``AuthorizedCertificates.DeleteAuthorizedCertificate``.

    Attributes:
        name (str):
            Name of the resource to delete. Example:
            ``apps/myapp/authorizedCertificates/12345``.
    """

    name = proto.Field(proto.STRING, number=1,)


class ListDomainMappingsRequest(proto.Message):
    r"""Request message for ``DomainMappings.ListDomainMappings``.
    Attributes:
        parent (str):
            Name of the parent Application resource. Example:
            ``apps/myapp``.
        page_size (int):
            Maximum results to return per page.
        page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListDomainMappingsResponse(proto.Message):
    r"""Response message for ``DomainMappings.ListDomainMappings``.
    Attributes:
        domain_mappings (Sequence[google.cloud.appengine_admin_v1.types.DomainMapping]):
            The domain mappings for the application.
        next_page_token (str):
            Continuation token for fetching the next page
            of results.
    """

    @property
    def raw_page(self):
        return self

    domain_mappings = proto.RepeatedField(
        proto.MESSAGE, number=1, message=ga_domain_mapping.DomainMapping,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetDomainMappingRequest(proto.Message):
    r"""Request message for ``DomainMappings.GetDomainMapping``.
    Attributes:
        name (str):
            Name of the resource requested. Example:
            ``apps/myapp/domainMappings/example.com``.
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateDomainMappingRequest(proto.Message):
    r"""Request message for ``DomainMappings.CreateDomainMapping``.
    Attributes:
        parent (str):
            Name of the parent Application resource. Example:
            ``apps/myapp``.
        domain_mapping (google.cloud.appengine_admin_v1.types.DomainMapping):
            Domain mapping configuration.
        override_strategy (google.cloud.appengine_admin_v1.types.DomainOverrideStrategy):
            Whether the domain creation should override
            any existing mappings for this domain. By
            default, overrides are rejected.
    """

    parent = proto.Field(proto.STRING, number=1,)
    domain_mapping = proto.Field(
        proto.MESSAGE, number=2, message=ga_domain_mapping.DomainMapping,
    )
    override_strategy = proto.Field(
        proto.ENUM, number=4, enum="DomainOverrideStrategy",
    )


class UpdateDomainMappingRequest(proto.Message):
    r"""Request message for ``DomainMappings.UpdateDomainMapping``.
    Attributes:
        name (str):
            Name of the resource to update. Example:
            ``apps/myapp/domainMappings/example.com``.
        domain_mapping (google.cloud.appengine_admin_v1.types.DomainMapping):
            A domain mapping containing the updated
            resource. Only fields set in the field mask will
            be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Standard field mask for the set of fields to
            be updated.
    """

    name = proto.Field(proto.STRING, number=1,)
    domain_mapping = proto.Field(
        proto.MESSAGE, number=2, message=ga_domain_mapping.DomainMapping,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeleteDomainMappingRequest(proto.Message):
    r"""Request message for ``DomainMappings.DeleteDomainMapping``.
    Attributes:
        name (str):
            Name of the resource to delete. Example:
            ``apps/myapp/domainMappings/example.com``.
    """

    name = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import Dict, Sequence, Tuple, Type, Union
import pkg_resources

import google.api_core.client_options as ClientOptions  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.appengine_admin_v1.services.authorized_certificates import pagers
from google.cloud.appengine_admin_v1.types import appengine
from google.cloud.appengine_admin_v1.types import certificate
from google.protobuf import timestamp_pb2  # type: ignore
from .transports.base import AuthorizedCertificatesTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
from .client import AuthorizedCertificatesClient


class AuthorizedCertificatesAsyncClient:
    """Manages SSL certificates a user is authorized to administer.
    A user can administer any SSL certificates applicable to their
    authorized domains.
    """

    _client: AuthorizedCertificatesClient

    DEFAULT_ENDPOINT = AuthorizedCertificatesClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = AuthorizedCertificatesClient.DEFAULT_MTLS_ENDPOINT

    common_billing_account_path = staticmethod(
        AuthorizedCertificatesClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        AuthorizedCertificatesClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(AuthorizedCertificatesClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        AuthorizedCertificatesClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        AuthorizedCertificatesClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        AuthorizedCertificatesClient.parse_common_organization_path
    )
    common_project_path = staticmethod(AuthorizedCertificatesClient.common_project_path)
    parse_common_project_path = staticmethod(
        AuthorizedCertificatesClient.parse_common_project_path
    )
    common_location_path = staticmethod(
        AuthorizedCertificatesClient.common_location_path
    )
    parse_common_location_path = staticmethod(
        AuthorizedCertificatesClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AuthorizedCertificatesAsyncClient: The constructed client.
        """
        return AuthorizedCertificatesClient.from_service_account_info.__func__(AuthorizedCertificatesAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AuthorizedCertificatesAsyncClient: The constructed client.
        """
        return AuthorizedCertificatesClient.from_service_account_file.__func__(AuthorizedCertificatesAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @property
    def transport(self) -> AuthorizedCertificatesTransport:
        """Returns the transport used by the client instance.

        Returns:
            AuthorizedCertificatesTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(AuthorizedCertificatesClient).get_transport_class,
        type(AuthorizedCertificatesClient),
    )

    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials = None,
        transport: Union[str, AuthorizedCertificatesTransport] = "grpc_asyncio",
        client_options: ClientOptions = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the authorized certificates client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.AuthorizedCertificatesTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = AuthorizedCertificatesClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def list_authorized_certificates(
        self,
        request: appengine.ListAuthorizedCertificatesRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListAuthorizedCertificatesAsyncPager:
        r"""Lists all SSL certificates the user is authorized to
        administer.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.ListAuthorizedCertificatesRequest`):
                The request object. Request message for
                `AuthorizedCertificates.ListAuthorizedCertificates`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.appengine_admin_v1.services.authorized_certificates.pagers.ListAuthorizedCertificatesAsyncPager:
                Response message for
                AuthorizedCertificates.ListAuthorizedCertificates.

                Iterating over this object will yield results and
                resolve additional pages automatically.

        """
        # Create or coerce a protobuf request object.
        request = appengine.ListAuthorizedCertificatesRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_authorized_certificates,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListAuthorizedCertificatesAsyncPager(
            method=rpc, request=request, response=response, metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_authorized_certificate(
        self,
        request: appengine.GetAuthorizedCertificateRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> certificate.AuthorizedCertificate:
        r"""Gets the specified SSL certificate.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.GetAuthorizedCertificateRequest`):
                The request object. Request message for
                `AuthorizedCertificates.GetAuthorizedCertificate`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.appengine_admin_v1.types.AuthorizedCertificate:
                An SSL certificate that a user has
                been authorized to administer. A user is
                authorized to administer any certificate
                that applies to one of their authorized
                domains.

        """
        # Create or coerce a protobuf request object.
        request = appengine.GetAuthorizedCertificateRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_authorized_certificate,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def create_authorized_certificate(
        self,
        request: appengine.CreateAuthorizedCertificateRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> certificate.AuthorizedCertificate:
        r"""Uploads the specified SSL certificate.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.CreateAuthorizedCertificateRequest`):
                The request object. Request message for
                `AuthorizedCertificates.CreateAuthorizedCertificate`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.appengine_admin_v1.types.AuthorizedCertificate:
                An SSL certificate that a user has
                been authorized to administer. A user is
                authorized to administer any certificate
                that applies to one of their authorized
                domains.

        """
        # Create or coerce a protobuf request object.
        request = appengine.CreateAuthorizedCertificateRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_authorized_certificate,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def update_authorized_certificate(
        self,
        request: appengine.UpdateAuthorizedCertificateRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> certificate.AuthorizedCertificate:
        r"""Updates the specified SSL certificate. To renew a certificate
        and maintain its existing domain mappings, update
        ``certificate_data`` with a new certificate. The new certificate
        must be applicable to the same domains as the original
        certificate. The certificate ``display_name`` may also be
        updated.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.UpdateAuthorizedCertificateRequest`):
                The request object. Request message for
                `AuthorizedCertificates.UpdateAuthorizedCertificate`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.appengine_admin_v1.types.AuthorizedCertificate:
                An SSL certificate that a user has
                been authorized to administer. A user is
                authorized to administer any certificate
                that applies to one of their authorized
                domains.

        """
        # Create or coerce a protobuf request object.
        request = appengine.UpdateAuthorizedCertificateRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_authorized_certificate,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def delete_authorized_certificate(
        self,
        request: appengine.DeleteAuthorizedCertificateRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes the specified SSL certificate.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.DeleteAuthorizedCertificateRequest`):
                The request object. Request message for
                `AuthorizedCertificates.DeleteAuthorizedCertificate`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        request = appengine.DeleteAuthorizedCertificateRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_authorized_certificate,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request, retry=retry, timeout=timeout, metadata=metadata,
        )


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-appengine-admin",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


__all__ = ("AuthorizedCertificatesAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import Dict, Sequence, Tuple, Type, Union
import pkg_resources

import google.api_core.client_options as ClientOptions  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.api_core import operation as gac_operation  # type: ignore
from google.api_core import operation_async  # type: ignore
from google.cloud.appengine_admin_v1.types import appengine
from google.cloud.appengine_admin_v1.types import application
from google.cloud.appengine_admin_v1.types import operation as ga_operation
from google.protobuf import duration_pb2  # type: ignore
from .transports.base import ApplicationsTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
from .client import ApplicationsClient


class ApplicationsAsyncClient:
    """Manages App Engine applications."""

    _client: ApplicationsClient

    DEFAULT_ENDPOINT = ApplicationsClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = ApplicationsClient.DEFAULT_MTLS_ENDPOINT

    common_billing_account_path = staticmethod(
        ApplicationsClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        ApplicationsClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(ApplicationsClient.common_folder_path)
    parse_common_folder_path = staticmethod(ApplicationsClient.parse_common_folder_path)
    common_organization_path = staticmethod(ApplicationsClient.common_organization_path)
    parse_common_organization_path = staticmethod(
        ApplicationsClient.parse_common_organization_path
    )
    common_project_path = staticmethod(ApplicationsClient.common_project_path)
    parse_common_project_path = staticmethod(
        ApplicationsClient.parse_common_project_path
    )
    common_location_path = staticmethod(ApplicationsClient.common_location_path)
    parse_common_location_path = staticmethod(
        ApplicationsClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            ApplicationsAsyncClient: The constructed client.
        """
        return ApplicationsClient.from_service_account_info.__func__(ApplicationsAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            ApplicationsAsyncClient: The constructed client.
        """
        return ApplicationsClient.from_service_account_file.__func__(ApplicationsAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @property
    def transport(self) -> ApplicationsTransport:
        """Returns the transport used by the client instance.

        Returns:
            ApplicationsTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(ApplicationsClient).get_transport_class, type(ApplicationsClient)
    )

    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials = None,
        transport: Union[str, ApplicationsTransport] = "grpc_asyncio",
        client_options: ClientOptions = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the applications client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.ApplicationsTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = ApplicationsClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def get_application(
        self,
        request: appengine.GetApplicationRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> application.Application:
        r"""Gets information about an application.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.GetApplicationRequest`):
                The request object. Request message for
                `Applications.GetApplication`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.appengine_admin_v1.types.Application:
                An Application resource contains the
                top-level configuration of an App Engine
                application.

        """
        # Create or coerce a protobuf request object.
        request = appengine.GetApplicationRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_application,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def create_application(
        self,
        request: appengine.CreateApplicationRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Creates an App Engine application for a Google Cloud Platform
        project. Required fields:

        -  ``id`` - The ID of the target Cloud Platform project.
        -  *location* - The
           `region <https://cloud.google.com/appengine/docs/locations>`__
           where you want the App Engine application located.

        For more information about App Engine applications, see
        `Managing Projects, Applications, and
        Billing <https://cloud.google.com/appengine/docs/standard/python/console/>`__.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.CreateApplicationRequest`):
                The request object. Request message for
                `Applications.CreateApplication`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.appengine_admin_v1.types.Application` An Application resource contains the top-level configuration of an App
                   Engine application.

        """
        # Create or coerce a protobuf request object.
        request = appengine.CreateApplicationRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_application,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            application.Application,
            metadata_type=ga_operation.OperationMetadataV1,
        )

        # Done; return the response.
        return response

    async def update_application(
        self,
        request: appengine.UpdateApplicationRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Updates the specified Application resource. You can update the
        following fields:

        -  ``auth_domain`` - Google authentication domain for
           controlling user access to the application.
        -  ``default_cookie_expiration`` - Cookie expiration policy for
           the application.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.UpdateApplicationRequest`):
                The request object. Request message for
                `Applications.UpdateApplication`.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.appengine_admin_v1.types.Application` An Application resource contains the top-level configuration of an App
                   Engine application.

        """
        # Create or coerce a protobuf request object.
        request = appengine.UpdateApplicationRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_application,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            application.Application,
            metadata_type=ga_operation.OperationMetadataV1,
        )

        # Done; return the response.
        return response

    async def repair_application(
        self,
        request: appengine.RepairApplicationRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Recreates the required App Engine features for the specified App
        Engine application, for example a Cloud Storage bucket or App
        Engine service account. Use this method if you receive an error
        message about a missing feature, for example, *Error retrieving
        the App Engine service account*. If you have deleted your App
        Engine service account, this will not be able to recreate it.
        Instead, you should attempt to use the IAM undelete API if
        possible at
        https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts/undelete?apix_params=%7B"name"%3A"projects%2F-%2FserviceAccounts%2Funique_id"%2C"resource"%3A%7B%7D%7D
        . If the deletion was recent, the numeric ID can be found in the
        Cloud Console Activity Log.

        Args:
            request (:class:`google.cloud.appengine_admin_v1.types.RepairApplicationRequest`):
                The request object. Request message for
                'Applications.RepairApplication'.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.appengine_admin_v1.types.Application` An Application resource contains the top-level configuration of an App
                   Engine application.

        """
        # Create or coerce a protobuf request object.
        request = appengine.RepairApplicationRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.repair_application,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            application.Application,
            metadata_type=ga_operation.OperationMetadataV1,
        )

        # Done; return the response.
        return response


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-appengine-admin",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


__all__ = ("ApplicationsAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import duration_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.appengine.v1",
    manifest={
        "Deployment",
        "FileInfo",
        "ContainerInfo",
        "CloudBuildOptions",
        "ZipInfo",
    },
)


class Deployment(proto.Message):
    r"""Code and application artifacts used to deploy a version to
    App Engine.

    Attributes:
        files (Sequence[google.cloud.appengine_admin_v1.types.Deployment.FilesEntry]):
            Manifest of the files stored in Google Cloud
            Storage that are included as part of this
            version. All files must be readable using the
            credentials supplied with this call.
        container (google.cloud.appengine_admin_v1.types.ContainerInfo):
            The Docker image for the container that runs
            the version. Only applicable for instances
            running in the App Engine flexible environment.
        zip_ (google.cloud.appengine_admin_v1.types.ZipInfo):
            The zip file for this deployment, if this is
            a zip deployment.
        cloud_build_options (google.cloud.appengine_admin_v1.types.CloudBuildOptions):
            Options for any Google Cloud Build builds
            created as a part of this deployment.

            These options will only be used if a new build
            is created, such as when deploying to the App
            Engine flexible environment using files or zip.
    """

    files = proto.MapField(proto.STRING, proto.MESSAGE, number=1, message="FileInfo",)
    container = proto.Field(proto.MESSAGE, number=2, message="ContainerInfo",)
    zip_ = proto.Field(proto.MESSAGE, number=3, message="ZipInfo",)
    cloud_build_options = proto.Field(
        proto.MESSAGE, number=6, message="CloudBuildOptions",
    )


class FileInfo(proto.Message):
    r"""Single source file that is part of the version to be
    deployed. Each source file that is deployed must be specified
    separately.

    Attributes:
        source_url (str):
            URL source to use to fetch this file. Must be
            a URL to a resource in Google Cloud Storage in
            the form
            'http(s)://storage.googleapis.com/\<bucket\>/\<object\>'.
        sha1_sum (str):
            The SHA1 hash of the file, in hex.
        mime_type (str):
            The MIME type of the file.
            Defaults to the value from Google Cloud Storage.
    """

    source_url = proto.Field(proto.STRING, number=1,)
    sha1_sum = proto.Field(proto.STRING, number=2,)
    mime_type = proto.Field(proto.STRING, number=3,)


class ContainerInfo(proto.Message):
    r"""Docker image that is used to create a container and start a
    VM instance for the version that you deploy. Only applicable for
    instances running in the App Engine flexible environment.

    Attributes:
        image (str):
            URI to the hosted container image in Google
            Container Registry. The URI must be fully
            qualified and include a tag or digest. Examples:
            "gcr.io/my-project/image:tag" or "gcr.io/my-
            project/image@digest".
    """

    image = proto.Field(proto.STRING, number=1,)


class CloudBuildOptions(proto.Message):
    r"""Options for the build operations performed as a part of the
    version deployment. Only applicable for App Engine flexible
    environment when creating a version using source code directly.

    Attributes:
        app_yaml_path (str):
            Path to the yaml file used in deployment,
            used to determine runtime configuration details.
            Required for flexible environment builds.

            See
            https://cloud.google.com/appengine/docs/standard/python/config/appref
            for more details.
        cloud_build_timeout (google.protobuf.duration_pb2.Duration):
            The Cloud Build timeout used as part of any
            dependent builds performed by version creation.
            Defaults to 10 minutes.
    """

    app_yaml_path = proto.Field(proto.STRING, number=1,)
    cloud_build_timeout = proto.Field(
        proto.MESSAGE, number=2, message=duration_pb2.Duration,
    )


class ZipInfo(proto.Message):
    r"""The zip file information for a zip deployment.
    Attributes:
        source_url (str):
            URL of the zip file to deploy from. Must be a
            URL to a resource in Google Cloud Storage in the
            form
            'http(s)://storage.googleapis.com/\<bucket\>/\<object\>'.
        files_count (int):
            An estimate of the number of files in a zip
            for a zip deployment. If set, must be greater
            than or equal to the actual number of files.
            Used for optimizing performance; if not
            provided, deployment may be slow.
    """

    source_url = proto.Field(proto.STRING, number=3,)
    files_count = proto.Field(proto.INT32, number=4,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.appengine.v1",
    manifest={
        "ManagementStatus",
        "AuthorizedCertificate",
        "CertificateRawData",
        "ManagedCertificate",
    },
)


class ManagementStatus(proto.Enum):
    r"""State of certificate management. Refers to the most recent
    certificate acquisition or renewal attempt.
    """
    MANAGEMENT_STATUS_UNSPECIFIED = 0
    OK = 1
    PENDING = 2
    FAILED_RETRYING_NOT_VISIBLE = 4
    FAILED_PERMANENT = 6
    FAILED_RETRYING_CAA_FORBIDDEN = 7
    FAILED_RETRYING_CAA_CHECKING = 8


class AuthorizedCertificate(proto.Message):
    r"""An SSL certificate that a user has been authorized to
    administer. A user is authorized to administer any certificate
    that applies to one of their authorized domains.

    Attributes:
        name (str):
            Full path to the ``AuthorizedCertificate`` resource in the
            API. Example: ``apps/myapp/authorizedCertificates/12345``.

            @OutputOnly
        id (str):
            Relative name of the certificate. This is a unique value
            autogenerated on ``AuthorizedCertificate`` resource
            creation. Example: ``12345``.

            @OutputOnly
        display_name (str):
            The user-specified display name of the certificate. This is
            not guaranteed to be unique. Example: ``My Certificate``.
        domain_names (Sequence[str]):
            Topmost applicable domains of this certificate. This
            certificate applies to these domains and their subdomains.
            Example: ``example.com``.

            @OutputOnly
        expire_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when this certificate expires. To update the
            renewal time on this certificate, upload an SSL certificate
            with a different expiration time using
            ```AuthorizedCertificates.UpdateAuthorizedCertificate`` <>`__.

            @OutputOnly
        certificate_raw_data (google.cloud.appengine_admin_v1.types.CertificateRawData):
            The SSL certificate serving the ``AuthorizedCertificate``
            resource. This must be obtained independently from a
            certificate authority.
        managed_certificate (google.cloud.appengine_admin_v1.types.ManagedCertificate):
            Only applicable if this certificate is managed by App
            Engine. Managed certificates are tied to the lifecycle of a
            ``DomainMapping`` and cannot be updated or deleted via the
            ``AuthorizedCertificates`` API. If this certificate is
            manually administered by the user, this field will be empty.

            @OutputOnly
        visible_domain_mappings (Sequence[str]):
            The full paths to user visible Domain Mapping resources that
            have this certificate mapped. Example:
            ``apps/myapp/domainMappings/example.com``.

            This may not represent the full list of mapped domain
            mappings if the user does not have ``VIEWER`` permissions on
            all of the applications that have this certificate mapped.
            See ``domain_mappings_count`` for a complete count.

            Only returned by ``GET`` or ``LIST`` requests when
            specifically requested by the ``view=FULL_CERTIFICATE``
            option.

            @OutputOnly
        domain_mappings_count (int):
            Aggregate count of the domain mappings with this certificate
            mapped. This count includes domain mappings on applications
            for which the user does not have ``VIEWER`` permissions.

            Only returned by ``GET`` or ``LIST`` requests when
            specifically requested by the ``view=FULL_CERTIFICATE``
            option.

            @OutputOnly
    """

    name = proto.Field(proto.STRING, number=1,)
    id = proto.Field(proto.STRING, number=2,)
    display_name = proto.Field(proto.STRING, number=3,)
    domain_names = proto.RepeatedField(proto.STRING, number=4,)
    expire_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
    certificate_raw_data = proto.Field(
        proto.MESSAGE, number=6, message="CertificateRawData",
    )
    managed_certificate = proto.Field(
        proto.MESSAGE, number=7, message="ManagedCertificate",
    )
    visible_domain_mappings = proto.RepeatedField(proto.STRING, number=8,)
    domain_mappings_count = proto.Field(proto.INT32, number=9,)


class CertificateRawData(proto.Message):
    r"""An SSL certificate obtained from a certificate authority.
    Attributes:
        public_certificate (str):
            PEM encoded x.509 public key certificate. This field is set
            once on certificate creation. Must include the header and
            footer. Example:

            .. raw:: html

                <pre>
                -----BEGIN CERTIFICATE-----
                <certificate_value>
                -----END CERTIFICATE-----
                </pre>
        private_key (str):
            Unencrypted PEM encoded RSA private key. This field is set
            once on certificate creation and then encrypted. The key
            size must be 2048 bits or fewer. Must include the header and
            footer. Example:

            .. raw:: html

                <pre>
                -----BEGIN RSA PRIVATE KEY-----
                <unencrypted_key_value>
                -----END RSA PRIVATE KEY-----
                </pre>

            @InputOnly
    """

    public_certificate = proto.Field(proto.STRING, number=1,)
    private_key = proto.Field(proto.STRING, number=2,)


class ManagedCertificate(proto.Message):
    r"""A certificate managed by App Engine.
    Attributes:
        last_renewal_time (google.protobuf.timestamp_pb2.Timestamp):
            Time at which the certificate was last renewed. The renewal
            process is fully managed. Certificate renewal will
            automatically occur before the certificate expires. Renewal
            errors can be tracked via ``ManagementStatus``.

            @OutputOnly
        status (google.cloud.appengine_admin_v1.types.ManagementStatus):
            Status of certificate management. Refers to
            the most recent certificate acquisition or
            renewal attempt.
            @OutputOnly
    """

    last_renewal_time = proto.Field(
        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
    )
    status = proto.Field(proto.ENUM, number=2, enum="ManagementStatus",)


__all__ = tuple(sorted(__protobuf__.manifest))
